netapp_ontap.models.volume_rebalancing1_engine_movement API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.volume_rebalancing1_engine_movement`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class VolumeRebalancing1EngineMovementSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the VolumeRebalancing1EngineMovement object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `file_moves_started: Size GET`

    Number of file moves started on this constituent.

  `last_error: VolumeRebalancing1EngineMovementLastError GET POST PATCH`

    The last_error field of the volume_rebalancing1_engine_movement.

  `most_recent_start_time: ImpreciseDateTime GET`

    Start time of the most recent file move on the constituent.

    Example: 2018-06-04T19:00:00.000+0000